@@ -273,7 +273,9 @@ def _anim_rst(anim, image_path, gallery_conf):
     dpi = rcParams["savefig.dpi"]
     if dpi == "figure":
         dpi = fig.dpi
-    video_uri = video.relative_to(gallery_conf["src_dir"]).as_posix()
+    # relative_to doesn't work on windows
+    # video_uri = video.relative_to(gallery_conf["src_dir"]).as_posix()
+    video_uri = PurePosixPath(os.path.relpath(video, gallery_conf["src_dir"]))
     html = _ANIMATION_VIDEO_RST.format(
         video=f"/{video_uri}",
         width=int(fig_size[0] * dpi),
@@ -397,8 +399,7 @@ def save_figures(block, block_vars, gallery_conf):
             )
             if not os.path.isfile(current_path):
                 raise ExtensionError(
-                    f"Scraper {scraper} did not produce expected image:"
-                    f"\n{current_path}"
+                    f"Scraper {scraper} did not produce expected image:\n{current_path}"
                 )
         all_rst += rst
     return all_rst
